@@ -12,14 +12,14 @@ class CompilerExtension(Extension):
     tags = set(['compress'])
 
     def parse(self, parser):
-        parser.stream.next()
+        lineno = parser.stream.next().lineno
         args = [parser.parse_expression()]
         body = parser.parse_statements(['name:endcompress'], drop_needle=True)
 
         if len(body) > 1:
             raise RuntimeError('One tag supported for now.')
 
-        return nodes.CallBlock(self.call_method('_compile', args), [], [], body)
+        return nodes.CallBlock(self.call_method('_compile', args), [], [], body).set_lineno(lineno)
 
     def _find_compilable_tags(self, soup):
         for link in soup.find_all('link'):
@@ -32,21 +32,31 @@ class CompilerExtension(Extension):
             yield script
 
     def _render_block(self, filename, type):
-        print filename
         filename = '%s/%s' % (self.environment.compressor_static_prefix, os.path.basename(filename))
 
         if type.lower() == 'css':
-            return '<link type="text/css" rel="stylesheet" src="%s" />' % filename
+            return '<link type="text/css" rel="stylesheet" href="%s" />' % filename
         elif type.lower() == 'js':
             return '<script type="text/javascript" src="%s"></script>' % filename
         else:
             raise RuntimeError('Unsupported type of compression %s' % type)
 
     def _find_file(self, path):
-        for d in self.environment.compressor_source_dir:
-            filename = os.path.join(d, path)
+        if callable(self.environment.compressor_source_dirs):
+            filename = self.environment.compressor_source_dirs(path)
+            print filename
             if os.path.exists(filename):
                 return filename
+        else:
+            if isinstance(self.environment.compressor_source_dirs, basestring):
+                dirs = [self.environment.compressor_source_dirs]
+            else:
+                dirs = self.environment.compressor_source_dirs
+
+            for d in dirs:
+                filename = os.path.join(d, path)
+                if os.path.exists(filename):
+                    return filename
 
         raise IOError(2, 'File not found %s' % path)
 
@@ -54,8 +64,8 @@ class CompilerExtension(Extension):
         html_hash = hashlib.sha256(html)
 
         for c in compilables:
-            if c.get('src'):
-                with open(self._find_file(c['src']), 'rb') as f:
+            if c.get('src') or c.get('href'):
+                with open(self._find_file(str(c.get('src') or c.get('href'))), 'rb') as f:
                     while True:
                         content = f.read(1024)
                         if content:
@@ -90,9 +100,9 @@ class CompilerExtension(Extension):
             if c.get('type') is None:
                 raise RuntimeError('Tags to be compressed must have a compression_type.')
 
-            src = c.get('src')
+            src = c.get('src') or c.get('href')
             if src:
-                src = open(self._find_file(src), 'rb')
+                src = open(self._find_file(str(src)), 'rb')
             else:
                 src = c.string
 
